containertools.get_first_element_starting_at_or_after_offset
============================================================

.. autofunction:: abjad.tools.containertools.get_first_element_starting_at_or_after_offset.get_first_element_starting_at_or_after_offset
   :noindex:
